@@ -18,13 +18,10 @@
  * <http://www.gnu.org/licenses/>.
  */
 
-#include "osinfo_device_driver.h"
+#pragma once
 
-#ifndef __OSINFO_DEVICE_DRIVER_PRIVATE_H__
-# define __OSINFO_DEVICE_DRIVER_PRIVATE_H__
+#include "osinfo_device_driver.h"
 
 OsinfoDeviceDriver *osinfo_device_driver_new(const gchar *id);
 void osinfo_device_driver_add_device(OsinfoDeviceDriver *driver,
                                      OsinfoDevice *device);
-
-#endif /* __OSINFO_DEVICE_DRIVER_PRIVATE_H__ */
