@@ -613,6 +613,7 @@ static OsinfoTree *load_keyinfo(const gchar *location,
                 goto cleanup;
             g_clear_error(error);
         }
+        g_clear_pointer(&group, g_free);
     }
 
     tree = osinfo_tree_new(location, arch ? arch : "i386");
@@ -1155,6 +1156,8 @@ OsinfoOsVariantList *osinfo_tree_get_os_variants(OsinfoTree *tree)
                                  OSINFO_LIST(os_variants),
                                  filter);
     }
+    g_list_free(ids);
+    g_object_unref(filter);
     g_object_unref(os_variants);
 
     return tree_variants;
